===========================
django-queryable-properties
===========================

.. image:: https://travis-ci.com/W1ldPo1nter/django-queryable-properties.svg?branch=master
   :target: https://travis-ci.com/W1ldPo1nter/django-queryable-properties
.. image:: https://codecov.io/gh/W1ldPo1nter/django-queryable-properties/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/W1ldPo1nter/django-queryable-properties
.. image:: https://readthedocs.org/projects/django-queryable-properties/badge/?version=latest
   :target: https://django-queryable-properties.readthedocs.io/en/latest/?badge=latest
.. image:: https://img.shields.io/pypi/v/django-queryable-properties.svg
   :target: https://pypi.org/project/django-queryable-properties

*django-queryable-properties* is a `Django`_ extension that allows to implement model properties which can be used
in database queries performed via Django's ORM.

.. _Django: https://www.djangoproject.com/

Further information, including supported Python and Django versions as well as installation instructions, can be found
in the `documentation hosted by readthedocs`_.

.. _documentation hosted by readthedocs: https://django-queryable-properties.readthedocs.io/

Contributing and getting help
=============================

The `GitHub repository`_ is the central place to report bugs and get help using the `GitHub issues`_ as well as to
contribute to the project via pull requests while following the `guide on contributing`_.

.. _GitHub repository: https://github.com/W1ldPo1nter/django-queryable-properties
.. _GitHub issues: https://github.com/W1ldPo1nter/django-queryable-properties/issues
.. _guide on contributing: https://github.com/W1ldPo1nter/django-queryable-properties/blob/master/CONTRIBUTING.rst
